# cs207-FinalProject
Final Project repository for Fall 2017 CS 207, Group 4

[![Build Status](https://travis-ci.org/cs207group4/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/cs207group4/cs207-FinalProject)
[![Coverage Status](https://coveralls.io/repos/github/cs207group4/cs207-FinalProject/badge.svg?branch=master&maxAge=0)](https://coveralls.io/github/cs207group4/cs207-FinalProject?branch=master&maxAge=0)

`doc` file is `usermanual.pdf`.

Individual classes are in `modules` folder. Run `sh make_chemkin.sh` will make a `chemkin.py` including all classes.

Please pull every time before working on it to avoid merge conflict.
